<?php
require_once(dirname(__FILE__) . "/lib/defines.php");

getpost_ifset(array('s'));
$s = $s ? $s : 0;

//LogOUt must be done before
if($s==9){
  header("location: ?action=logOut");
  exit;
}

//Left Menu config
$array = array (
  0 => "CDR Report",
  1 => "Calls Compare",
  2 => "Monthly Traffic",
  3 => "Daily Load");
if (  USER_CAN_CHPASS != 0 || $_SESSION['admin'] == 1 )  $array[4]="User Settings";
if ( $_SESSION['admin'] == 1  )  $array[14]="Users List";
if ( $_SESSION['admin'] == 1  )  $array[16]="User Create";
$array[10] = "Logs Filter";
if ( PURGE != 0 && $_SESSION['admin'] == 1  )  $array[5]="Purge History";
$array[9]=$_SESSION["username"]." Logout";



?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html>
	<head>		
		<title>Asterisk CDR</title>
		<meta http-equiv="Content-Type" content="text/html">
		<style type="text/css" media="screen">
			@import url("css/layout.css");
			@import url("css/content.css");
			@import url("css/docbook.css");
		</style>
		<meta name="MSSmartTagsPreventParsing" content="TRUE">
	</head>
	<body>
		<!-- header BEGIN -->
		<div id="fedora-header">
			<div id="fedora-header-logo">
				 <table cellpadding="0" cellspacing="0"><tr><td><img src="<?php echo LOGOFILE?>"  alt="CDR (Call Detail Records)"></td>
      </tr></table>
			</div>  	
    </div>		
		<!-- header END -->
		
		<!-- leftside BEGIN -->
		<div id="fedora-side-left">       
      <ul id="fedora-side-nav">
      <?php 
      foreach ($array as $key => $value) {
        $op_strong = ($key==$s) ? '<strong>' : '';
        $cl_strong = ($key==$s) ? '</strong>' : '';
        echo "\n\t<li>$op_strong<a href=\"?s=$key\">".$value."</a>$cl_strong";

       }
		  ?>
	    </ul>
		</div>
		<!-- leftside END -->

		<!-- content BEGIN -->
		<div id="fedora-middle-two">
			<div class="fedora-corner-tr">&nbsp;</div>
			<div class="fedora-corner-tl">&nbsp;</div>
			<div id="fedora-content">



<?php
switch($s){
  case 0:
    require_once("call-log.php");break;
  case 1:
    require_once("call-comp.php");break;
  case 2:
    require_once("call-last-month.php");break;
  case 3:
    require_once("call-daily-load.php");break;
  case 4:
    require_once("edituser.php");break;
  case 5:
    require_once("call-purge.php");break;
//  case 9: //done at begin
//  header("location: ?action=logOut");exit;
  case 10:
	require_once("logfilter.php");break;
  case 14:
    require_once("listusers.php");break;
  case 16:
    require_once("newuser.php");break;
  case 21:
	require_once("staticAll.php");break;
  case 22:
	require_once("staticRecognizeMSGErr.php");break;
  case 23:
	require_once("staticMSGErr.php");break;
  case 24:
	require_once("staticCustom.php");break;
  case 29:
	require_once("staticErrors.php");break;
  case 31:
	require_once("dynamicAll.php");break;
  case 32:
	require_once("dynamicRecognizeMSGErr.php");break;
  case 33:
	require_once("dynamicMSGErr.php");break;
  case 34:
	require_once("dynamicCustom.php");break;
  case 39:
	require_once("dynamicErrors.php");break;
  default:
  ?>
		<h1>About</h1> 		
	  <table width="90%">
	  <tr> 
  	  <td>
      <?php echo ABOUT?>
      </td>
    </tr>    
	  </table>
  <br><br><em><strong>Last update:</strong></em> <?php echo strtr($update,array(': '=>'', '$'=>''))?><br>
  <?php


}?>
		
		<br><br><br><br><br><br>
		</div>

			<div class="fedora-corner-br">&nbsp;</div>
			<div class="fedora-corner-bl">&nbsp;</div>
		</div>
		<!-- content END -->
		
		<!-- footer BEGIN -->
		<div id="fedora-footer">
<a href="?s=99">CDR Asterisk : about</a>
			<br>			
		</div>
		<!-- footer END -->
	</body>
</html>
